using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class EnemyController : MonoBehaviour
{
    Animator animator;
    GameObject unitychanObject;
    float near = 200.0f;
    float nearstop = 1.0f;
    bool punching;
    float punchingTime;
    float punchingTimePeriod = 1.0f;
    int attack;
    public int attackOver = 10;
    float clearDamageTime;
    float clearDamageTimePeriod = 10.0f;
    public AudioClip smallAudioClip;
    public AudioClip largeAudioClip;

    // Start is called before the first frame update
    void Start()
    {
        this.animator = GetComponent<Animator>();
        this.unitychanObject = GameObject.FindWithTag("unitychan");
        this.punching = false;
        this.attack = 0;
    }

    // Update is called once per frame
    void Update()
    {
        if (!this.unitychanObject.GetComponent<UnitychanController>().
            IsUnitychanAlive())
        {
            this.animator.SetBool("walk", false);
            return;
        }

        float distance = Vector3.Distance(gameObject.transform.position,
            this.unitychanObject.transform.position);
        if (distance < this.near && !this.punching)
        {
            gameObject.transform.LookAt(this.unitychanObject.transform);
            if (distance > this.nearstop)
            {
                this.animator.SetBool("walk", true);
                gameObject.transform.position +=
                    gameObject.transform.forward * 0.01f;
            }
            else
            {
                if (!this.punching)
                {
                    this.animator.SetBool("walk", false);
                    this.animator.SetBool("punch", true);
                    this.punching = true;
                    this.punchingTime = 0.0f;
                }
            }
        }
        if (this.punching)
        {
            this.punchingTime += Time.deltaTime;
            if (this.punchingTime > this.punchingTimePeriod)
            {
                this.animator.SetBool("punch", false);
                this.punching = false;
            }
        }

        this.clearDamageTime += Time.deltaTime;
        if (this.clearDamageTime > this.clearDamageTimePeriod)
        {
            this.clearDamageTime = 0;
            if (this.attack > 0)
            {
                this.attack = 0;
                Debug.Log("(enemy) unitychan damage cleared");
            }
        }
    }

    void OnTriggerEnter(Collider collision)
    {
        if (this.unitychanObject == null)
        {
            return;
        }
        if (!this.unitychanObject.GetComponent<UnitychanController>().
            IsUnitychanAlive())
        {
            return;
        }
        string tag = collision.gameObject.tag;
        if (tag == "unitychan")
        {
            if (this.animator.GetBool("punch"))
            {
                this.attack++;
                Debug.Log("enemy punch(attack " + this.attack + ")");
                if (this.attack >= this.attackOver)
                {
                    this.unitychanObject.GetComponent<UnitychanController>().
                        UnitychanDead();
                    GetComponent<AudioSource>().PlayOneShot(this.largeAudioClip);
                } else
                {
                    GetComponent<AudioSource>().PlayOneShot(this.smallAudioClip);
                }
                this.clearDamageTime = 0.0f;
            }
        }
    }
}
