using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;
using UnityEngine.UI;

public class UnitychanController : MonoBehaviour
{
    Animator animator;
    int[] attack;
    public int attackOver = 5;
    float[] clearDamageTime;
    float clearDamageTimePeriod = 10.0f;
    int win;
    bool unitychanAlive;
    //int enemyNum = 2; // 仮設定
    int enemyNum;
    GameObject eGeneratorObject;
    public AudioClip smallAudioClip;
    public AudioClip largeAudioClip;
    public Material skyboxClear;
    GameObject uiObject;

    // Start is called before the first frame update
    void Start()
    {
        this.animator = GetComponent<Animator>();
        this.eGeneratorObject = GameObject.FindWithTag("enemygenerator");
        this.enemyNum = this.eGeneratorObject.GetComponent<EnemyGenerator>().
            GetEnemyNumber();
        this.attack = new int[this.enemyNum];
        for (int i = 0; i < this.enemyNum; i++)
        {
            this.attack[i] = 0;
        }
        this.clearDamageTime = new float[this.enemyNum];
        this.win = 0;
        this.unitychanAlive = true;
        this.uiObject = GameObject.FindWithTag("ui");
    }

    // Update is called once per frame
    void Update()
    {
        if (!IsUnitychanAlive())
        {
            return;
        }

        if (Input.GetKeyDown(KeyCode.UpArrow) &&
            !this.animator.GetBool("back"))
        {
            this.animator.SetBool("walk", true);
        }
        if (Input.GetKeyUp(KeyCode.UpArrow))
        {
            this.animator.SetBool("walk", false);
            this.animator.SetBool("run", false);
        }
        if (Input.GetKeyDown(KeyCode.LeftShift) &&
            this.animator.GetBool("walk"))
        {
            this.animator.SetBool("run", true);
        }
        if (Input.GetKeyUp(KeyCode.LeftShift))
        {
            this.animator.SetBool("run", false);
        }
        if (this.animator.GetBool("walk"))
        {
            Vector3 position;
            if (this.animator.GetBool("run"))
            {
                position = gameObject.transform.position +
                    gameObject.transform.forward * 0.03f;
            }
            else
            {
                position = gameObject.transform.position +
                    gameObject.transform.forward * 0.01f;
            }
            gameObject.transform.position = position;
        }

        if (Input.GetKeyDown(KeyCode.DownArrow) &&
            !this.animator.GetBool("walk"))
        {
            this.animator.SetBool("back", true);
        }
        if (Input.GetKeyUp(KeyCode.DownArrow))
        {
            this.animator.SetBool("back", false);
        }
        if (this.animator.GetBool("back"))
        {
            Vector3 position;
            position = gameObject.transform.position -
                gameObject.transform.forward * 0.01f;
            gameObject.transform.position = position;
        }

        if (Input.GetKeyDown(KeyCode.LeftArrow))
        {
            gameObject.transform.Rotate(0, -10.0f, 0);
        }
        if (Input.GetKeyDown(KeyCode.RightArrow))
        {
            gameObject.transform.Rotate(0, 10.0f, 0);
        }

        if (Input.GetKeyDown(KeyCode.R) &&
            !this.animator.GetBool("run"))
        {
            this.animator.SetBool("punch", true);
            this.animator.SetBool("walk", false);
            this.animator.SetBool("back", false);
        }
        if (Input.GetKeyUp(KeyCode.R))
        {
            this.animator.SetBool("punch", false);
        }
        if (Input.GetKeyDown(KeyCode.W) &&
            !this.animator.GetBool("run"))
        {
            this.animator.SetBool("kick", true);
            this.animator.SetBool("walk", false);
            this.animator.SetBool("back", false);
        }
        if (Input.GetKeyUp(KeyCode.W))
        {
            this.animator.SetBool("kick", false);
        }

        for (int i = 0; i < this.enemyNum; i++)
        {
            this.clearDamageTime[i] += Time.deltaTime;
            if (this.clearDamageTime[i] > this.clearDamageTimePeriod)
            {
                this.clearDamageTime[i] = 0;
                if (this.attack[i] > 0)
                {
                    this.attack[i] = 0;
                    Debug.Log("(unitychan) enemy" + i + " damage cleared)");
                }
            }
        }

        if (transform.position.y < -30.0f)
        {
            SceneManager.LoadScene(SceneManager.GetActiveScene().name);
        }
    }

    void OnTriggerEnter(Collider collision)
    {
        if (!IsUnitychanAlive())
        {
            return;
        }
        string tag = collision.gameObject.tag;
        if (tag.Length == 7 && tag.Substring(0, 5) == "enemy")
        {
            if (this.animator.GetBool("punch") || this.animator.GetBool("kick"))
            {
                int inum = int.Parse(tag.Substring(5, 2));
                this.attack[inum]++;
                Debug.Log("unitychan punch or kick(attack " + this.attack[inum] + ")");
                if (this.attack[inum] >= this.attackOver)
                {
                    Destroy(collision.gameObject);
                    this.win++;
                    GetComponent<AudioSource>().PlayOneShot(this.largeAudioClip);
                    if (this.win == this.enemyNum)
                    {
                        RenderSettings.skybox = this.skyboxClear;
                    }
                } else
                {
                    GetComponent<AudioSource>().PlayOneShot(this.smallAudioClip);
                }
                this.clearDamageTime[inum] = 0.0f;
            }
        }
    }

    public void UnitychanDead()
    {
        this.unitychanAlive = false;
        this.uiObject.GetComponent<Text>().text = "Lost World";
    }

    public bool IsUnitychanAlive()
    {
        return this.unitychanAlive;
    }

    public int GetWinNum()
    {
        return this.win;
    }

    public void UnitychanSavedWorld()
    {
        this.uiObject.GetComponent<Text>().text = "Saved World";
    }
}
